from django.apps import AppConfig
from pathlib import Path
from django.db.models.signals import post_migrate


def read_pages(sender, **kwargs):
    from .models import Page

    print("pages init")
    content_path = Path(__file__).resolve().parent / "default_content"
    for file in content_path.iterdir():
        slug = file.stem
        p, created = Page.objects.get_or_create(url=slug)
        if not created:
            continue
        p.content = file.read_text()
        p.title = slug
        p.save()
        print(f"created new page for slug {slug}")


class PagesConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "shiftregister.pages"

    def ready(self):
        # we use thios signal so our code is not called before the schema is migrated
        # and not during makemigrations/migrate
        post_migrate.connect(read_pages, sender=self)
